<?php

namespace Drupal\qtools_transport_profiler\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\qtools_transport_profiler\ReportService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Controller for requests report.
 */
class RequestReportController extends ControllerBase {

  /**
   * Drupal\qtools_transport_profiler\ReportService.
   *
   * @var \Drupal\qtools_transport_profiler\ReportService
   */
  protected $reportService;

  /**
   * Drupal\Core\Form\FormBuilderInterface.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * Symfony\Component\HttpFoundation\RequestStack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    ReportService $reportService,
    FormBuilderInterface $formBuilder,
    RequestStack $requestStack
  ) {
    $this->reportService = $reportService;
    $this->formBuilder = $formBuilder;
    $this->requestStack = $requestStack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('qtools_transport_profiler.report'),
      $container->get('form_builder'),
      $container->get('request_stack')
    );
  }

  /**
   * Returns page content.
   *
   * @return array
   *   Page array.
   */
  public function pageBuild() {

    // Get filter values.
    $route = $this->requestStack->getCurrentRequest()->query->get('route');
    $service = $this->requestStack->getCurrentRequest()->query->get('service');

    // Get filter form.
    $build['form'] = $this->formBuilder->getForm('\Drupal\qtools_transport_profiler\Form\ReportFilterForm');

    // Get report table.
    $filters = [
      'service' => $service,
      'route' => $route,
    ] + $this->reportService->getReportFilters();
    $header = $this->reportService->reportRequestTableHeader($filters);
    $query = $this->reportService->reportRequestBaseQuery($filters);
    $results = $query->execute()->fetchAll();
    $rows = $this->reportService->reportRequestProcessResults($results, $filters);

    $build['table'] = [
      '#type' => 'table',
      '#rows' => $rows,
      '#header' => $header,
      '#cache' => [
        'max-age' => -1,
      ],
    ];

    $build['pager'] = [
      '#type' => 'pager',
    ];

    return $build;
  }

}
